classdef Model < handle
    %MODEL DNWR and SRAS model
    %   Provides access to the parameters and solution to model
    %
    %   Properties
    %   ----------
    %   Name            Name of the model object
    %   Parameters      Model parameters
    %   FirstBest       First-best equilibrium without DNWR, etc.
    %   FlexWage        Flexible wage equilibrium
    %   SteadyState     Steady-state equilibrium
    %   TransitionPath  Transitional dynamics of model for given shock
    %   Display         Boolean to turn display of iterations on and off
    %
        
    properties
    
        Name = 'DNWR and SRAS'
        Display = 1
        Server = 0
    
    end
    
    properties ( SetAccess = private , Hidden = false )
    
        Type = 'model'
        Numerics
        SteadyState
        TransitionPath
        Parameters
        
    end
    
    properties ( Dependent = true , SetAccess = private )
            
        FirstBest
        FlexWage
        
    end
    
    methods 
       
        function obj = Model
            obj.Numerics = DNWR.Numerics( obj ); 
            obj.Parameters = DNWR.Parameters( obj );
            obj.SteadyState = DNWR.SteadyState( obj );            
            obj.TransitionPath = DNWR.TransitionPath( obj );
        end         
        
        
        function obj = set.Name(obj,val)
           obj.Name = val;
        end
        
        function obj = set.Display(obj,val)
           obj.Display = val;
        end
        
        function firstbest = get.FirstBest( obj )
        
            firstbest = DNWR.FirstBest( obj );
            
        end
        
        function flexwage = get.FlexWage( obj )
        
            flexwage = DNWR.FlexWage( obj );
            
        end
            
    end
    
end

