function [ H04Q_ ] = H04QCalculation( G_tminus4_wp , Z_t_wp , Pit , a_t , Model )
%H04QCalculation Calculates the spike at zero wage changes over 4 quarters.

Lamda = Model.Parameters.Lamda;

if ( size( Z_t_wp , 1 ) == 4 )
   
elseif ( size( Z_t_wp , 1 ) == 1 )
    
    Z_t_wp = [ Z_t_wp ; Z_t_wp ; Z_t_wp ; Z_t_wp ];
    Pit = [ Pit ; Pit ; Pit ; Pit ];
    a_t = [ a_t ; a_t ; a_t ; a_t ];
    
else
   
    error('H04QCalculation only takes steady state or 4 quarters as input')
    
end

wMax_tminus4 = max( G_tminus4_wp.breaks );
wMin_tminus4 = min( G_tminus4_wp.breaks );

GridPoints = Model.Numerics.wPoints;
wg = wMin_tminus4 + ...
    (cumsum(ones(GridPoints,1))-1).*(wMax_tminus4-wMin_tminus4)./(GridPoints-1);

Z_t_w = polyval( Z_t_wp(4,:) , wg./ ...
       ((1+Pit(4,1)).*(1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(4,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_t_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_t_w ) );
[ f_t_Z , F_t_Z ] = ShockDistribution( Z_t_w , Model );
Z_tminus1_w = polyval( Z_t_wp(3,:) , wg./ ...
       ((1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus1_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus1_w ) );
[ f_tminus1_Z , F_tminus1_Z ] = ShockDistribution( Z_tminus1_w , Model );
Z_tminus2_w = polyval( Z_t_wp(2,:) , wg./ ...
       ((1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus2_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus2_w ) );
[ f_tminus2_Z , F_tminus2_Z ] = ShockDistribution( Z_tminus2_w , Model );
Z_tminus3_w = polyval( Z_t_wp(1,:) , wg./((1+Pit(1,1)).*(1+a_t(1,1)) ) );
Z_tminus3_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus3_w ) );
[ f_tminus3_Z , F_tminus3_Z ] = ShockDistribution( Z_tminus3_w , Model );

G_tminus4_wg = ppvalcutoff( G_tminus4_wp , wg , 0  , 1 );
FGg = F_t_Z.*F_tminus1_Z.*F_tminus2_Z.*F_tminus3_Z.*G_tminus4_wg ;
FGp = pchip( wg , FGg );
FGpint = ppint( FGp );

H04Q_ = (Lamda.^4).*(ppval(FGpint,wMax_tminus4)-ppval(FGpint,wMin_tminus4));

end

