function [ h4Qnegp , h4Qposp  , H4Qnegp , h4Qposp ] = H4QCalculation( G_t_wp , G_tminus4_wp , Z_t_wp , Pit , a_t , Model )
%H4QCalculation Calculates the distribution and density function for 4-quarter wage changes.

Lamda = Model.Parameters.Lamda;

if ( size( Z_t_wp , 1 ) == 4 )
   
elseif ( size( Z_t_wp , 1 ) == 1 )
    
    Z_t_wp = [ Z_t_wp ; Z_t_wp ; Z_t_wp ; Z_t_wp ];
    Pit = [ Pit ; Pit ; Pit ; Pit ];
    a_t = [ a_t ; a_t ; a_t ; a_t ];
    
else
   
    error('H04QCalculation only takes steady state or 4 quarters as input')
    
end

wMax_tminus4 = max( G_tminus4_wp.breaks );
wMin_tminus4 = min( G_tminus4_wp.breaks );
wMax_t = max( G_t_wp.breaks );
wMin_t = min( G_t_wp.breaks );
dlnwMin = log(wMin_t) - log(wMax_tminus4) + ... 
	  log((1+Pit(4,1)).*(1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(4,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) ;
dlnwMax = log(wMax_t) - log(wMin_tminus4) + ...
          log((1+Pit(4,1)).*(1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(4,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) ;

GridPoints = Model.Numerics.wPoints;
wg = wMin_tminus4 + ...
    (cumsum(ones(GridPoints,1))-1).*(wMax_tminus4-wMin_tminus4)./(GridPoints-1);
dlnwnegg = dlnwMin + (cumsum(ones(GridPoints,1))-1).*(-0.00005-dlnwMin)./(GridPoints-1);
dlnwposg = 0.00005 + (cumsum(ones(GridPoints,1))-1).*(dlnwMax-0.00005)./(GridPoints-1);
wg = kron( wg , ones( 1 , size(dlnwnegg , 1 ) ) );
dlnwnegg = kron( ones( size( wg , 1 ) , transpose(dlnwnegg) );
dlnwposg = kron( ones( size( wg , 1 ) , transpose(dlnwposg) );

Z_t_w = polyval( Z_t_wp(4,:) , exp(dlnwnegg).*wg./ ...
       ((1+Pit(4,1)).*(1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(4,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_t_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_t_w ) );
[ f_t_Z , F_t_Z ] = ShockDistribution( Z_t_w , Model );
Z_tminus1_w = polyval( Z_t_wp(3,:) , exp(dlnwnegg).*wg./ ...
       ((1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus1_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus1_w ) );
[ f_tminus1_Z , F_tminus1_Z ] = ShockDistribution( Z_tminus1_w , Model );
Z_tminus2_w = polyval( Z_t_wp(2,:) , exp(dlnwnegg).*wg./ ...
       ((1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus2_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus2_w ) );
[ f_tminus2_Z , F_tminus2_Z ] = ShockDistribution( Z_tminus2_w , Model );
Z_tminus3_w = polyval( Z_t_wp(1,:) , exp(dlnwnegg).*wg./((1+Pit(1,1)).*(1+a_t(1,1)) ) );
Z_tminus3_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus3_w ) );
[ f_tminus3_Z , F_tminus3_Z ] = ShockDistribution( Z_tminus3_w , Model );

M4_tminus4_wg = (1-Lamda).*F_t_Z + ...
               Lamda.*(1-Lamda).*F_t_Z.*F_tminus1_Z + ...
               (Lamda^2).*(1-Lamda).*.*F_t_Z.*F_tminus1_Z.*F_tminus2_Z + ...
               (Lamda^3).*(1-Lamda).*.*F_t_Z.*F_tminus1_Z.*F_tminus2_Z.*F_tminus3_Z ;
               
G_tminus4_wg = ppvalcutoff( G_tminus4_wp , wg , 0  , 1 );
g_tminus4_wp = ppder( G_tminus4_wp );
g_tminus4_wg = ppvalcutoff( g_tminus4_wp , wg , 0 , 0 );

H4_tminus4_wg = M4_tminus4_wg.*g_tminus4_wg;
H4_tminus4_dlnwnegg = zeros(size(dlnwnegg,2),1);

for idlnw = 1:size(dlnwnegg,2);

	H4p = pchip( wg(:,idlnw) , H4_tminus4_wg(:,idlnw) );
	H4pint = ppint( H4p );
	H4_tminus4_dlnwnegg(idlnw,1) = (ppval(H4pint,wMax_tminus4)-ppval(H4pint,wMin_tminus4))

end

H4Qnegp = pchip( transpose( dlnwnegg(1,:) ) , H4_tminus4_dlnwnegg );
h4Qnegp = ppder( H4qnegp );

Z_t_w = polyval( Z_t_wp(4,:) , exp(dlnwposg).*wg./ ...
       ((1+Pit(4,1)).*(1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(4,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_t_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_t_w ) );
[ f_t_Z , F_t_Z ] = ShockDistribution( Z_t_w , Model );
Z_tminus1_w = polyval( Z_t_wp(3,:) , exp(dlnwposg).*wg./ ...
       ((1+Pit(3,1)).*(1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(3,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus1_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus1_w ) );
[ f_tminus1_Z , F_tminus1_Z ] = ShockDistribution( Z_tminus1_w , Model );
Z_tminus2_w = polyval( Z_t_wp(2,:) , exp(dlnwposg).*wg./ ...
       ((1+Pit(2,1)).*(1+Pit(1,1)).*(1+a_t(2,1)).*(1+a_t(1,1)) ) );
Z_tminus2_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus2_w ) );
[ f_tminus2_Z , F_tminus2_Z ] = ShockDistribution( Z_tminus2_w , Model );
Z_tminus3_w = polyval( Z_t_wp(1,:) , exp(dlnwposg).*wg./((1+Pit(1,1)).*(1+a_t(1,1)) ) );
Z_tminus3_w = max( Model.Numerics.ZLow ,  min( Model.Numerics.ZUp , Z_tminus3_w ) );
[ f_tminus3_Z , F_tminus3_Z ] = ShockDistribution( Z_tminus3_w , Model );

M4_tminus4_wg = (1-Lamda).*F_t_Z + ...
               Lamda.*(1-Lamda).*F_t_Z.*F_tminus1_Z + ...
               (Lamda^2).*(1-Lamda).*.*F_t_Z.*F_tminus1_Z.*F_tminus2_Z + ...
               (Lamda^3).*(1-Lamda).*.*F_t_Z.*F_tminus1_Z.*F_tminus2_Z.*F_tminus3_Z ;
               
G_tminus4_wg = ppvalcutoff( G_tminus4_wp , wg , 0  , 1 );
g_tminus4_wp = ppder( G_tminus4_wp );
g_tminus4_wg = ppvalcutoff( g_tminus4_wp , wg , 0 , 0 );

H4_tminus4_wg = M4_tminus4_wg.*g_tminus4_wg;
H4_tminus4_dlnwposg = zeros(size(dlnwnegg,2),1);

for idlnw = 1:size(dlnwposg,2);

	H4p = pchip( wg(:,idlnw) , H4_tminus4_wg(:,idlnw) );
	H4pint = ppint( H4p );
	H4_tminus4_dlnwposg(idlnw,1) = (ppval(H4pint,wMax_tminus4)-ppval(H4pint,wMin_tminus4));

end

H4Qposp = pchip( transpose( dlnwposg(1,:) ) , H4_tminus4_dlnwposg );
h4Qposp = ppder( H4qposp );

end

