function [ w_t_Z ] = OptimalWageSetting( Z , V_tplus1_wp , L , D , Pitplus1 , a_tplus1 , Model )

Eta = Model.Parameters.Eta;
Gam = Model.Parameters.Gamma;
ZUp = Model.Numerics.ZUp;
Beta = Model.Parameters.Beta;

wHat= (((Eta./(Eta-1)).*Z).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) );
wUp = 1.25.*wHat;       
                
V0 = polyval( V_tplus1_wp , 0 );
CriticalPoint = (1-(Gam./(Gam+1)).*Z.*(L.^((Gam+1)./Gam))); 

if ( CriticalPoint < -1.*(Beta.*exp(-D)).*V0 )

    wLow = 1;
    
else
    
    wCheckg = 0:100;
    wCheckg = 0.01.*wCheckg';
    UtilityCheckg = UtilityFunction( wCheckg , Z , L , Model );
    wLow = min( wCheckg.*(UtilityCheckg >= -(Beta.^(-D)).*V0) + ...
                         (UtilityCheckg < -(Beta.^(-D)).*V0) );
    if wLow > wHat 
        wLow = wHat-0.01;
    end
end
               
GridPoints = Model.Numerics.wPoints;
wGrid = wLow + (cumsum(ones(GridPoints,1))-1).*(wUp-wLow)/(GridPoints-1);
wGrid = [ wGrid ; wHat ];
Utilityg = UtilityFunction( wGrid , Z , L , Model );
ContinuationVg = (Beta.*exp(-D)).*polyval( V_tplus1_wp , wGrid./((1+Pitplus1).*(1+a_tplus1)) );
Objectivep = polyfit( wGrid , (Utilityg+ContinuationVg) , Model.Numerics.PolyOrder );
Derivativep = polyder(Objectivep);

wRoots = roots( Derivativep );
wRootsSelect = ((imag(wRoots) == 0 )&( wRoots <= wHat )&( wRoots > 0 ));
if sum( wRootsSelect == 0 )        
    wRoots = [ wHat ; wLow ];            
else                
    wRoots = [ wRoots( wRootsSelect , : ) ; wLow ];                        
end                  
UtilityRoots = UtilityFunction( wRoots , Z , L , Model );
ContinuationVRoots = (Beta.*exp(-D)).*polyval( V_tplus1_wp , wRoots./((1+Pitplus1).*(1+a_tplus1)) );
ObjectiveRoots = UtilityRoots+ContinuationVRoots;
ObjectiveMax = ( ObjectiveRoots == max(ObjectiveRoots) ); 
ObjectiveRoots = ObjectiveRoots( ObjectiveMax , : );
ObjectiveRoots = ObjectiveRoots( 1 , : );
wRoots = wRoots( ObjectiveMax , : );
wRoots = wRoots( 1 , : );

w_t_Z = real(wRoots);

end