function [ Q ] = PolyFZInt( p , r , a , b , Model )
%PolyFzInt Calculates integral over function
%    (Z^r).*p(Z).*f(Z) from a to b

Sigma = Model.Parameters.Sigma;
Mu = -1.*0.5.*(Sigma^2);
rvec = r+flipud(cumsum(ones(size(p,2),1))-1);

F_ZUp = normcdf( log(Model.Numerics.ZUp) , Mu , Sigma );
F_ZLow = normcdf( log(Model.Numerics.ZLow) , Mu , Sigma );
Rescale = F_ZUp - F_ZLow ;

a = max(a,Model.Numerics.ZLow);
b = min(b,Model.Numerics.ZUp);

atilde = ( log(a)+ 0.5.*(Sigma^2) )./Sigma ;
btilde = ( log(b)+ 0.5.*(Sigma^2) )./Sigma ;

Q = exp(0.5.*rvec.*(rvec-1).*(Sigma^2)).* ... 
    ( normcdf( rvec.*Sigma - atilde , 0 , 1 ) - normcdf( rvec.*Sigma - btilde , 0 , 1 ) );
Q = Q./Rescale;
Q = sum( (p').*Q );

end

