function [ f_Z , F_Z ] = ShockDistribution( Z , Model )
%ShockDistribution Evaluates density and distribution function of
%idiosyncratic productivity shocks.

ZUp = Model.Numerics.ZUp;
ZLow = Model.Numerics.ZLow;
F_ZUp = normcdf( log(ZUp) , -0.5*(Model.Parameters.Sigma)^2 ,Model.Parameters.Sigma );
F_ZLow = normcdf( log(ZLow) , -0.5*(Model.Parameters.Sigma)^2 ,Model.Parameters.Sigma );
Rescale = F_ZUp - F_ZLow ;

f_Z = normpdf( log(Z) , -0.5*(Model.Parameters.Sigma)^2 , Model.Parameters.Sigma )./Z ;
f_Z = (Z < ZUp).*(Z > ZLow).*f_Z./Rescale;
F_Z = normcdf( log(Z) , -0.5*(Model.Parameters.Sigma)^2 , Model.Parameters.Sigma );
F_Z = min( max( F_Z , 0 ) , 1 );
F_Z = ( F_Z - F_ZLow )./Rescale;

end

