function [ w_t_Zp , Z_t_wp , V_t_wp ] = ValueFunctionIteration( V_tplus1_wp , L , D , Pitplus1 , a_tplus1 , Model )

Gam = Model.Parameters.Gamma;
Eta = Model.Parameters.Eta;
Lamda = Model.Parameters.Lamda;
Beta = Model.Parameters.Beta;

% This part solves the optimal wage-setting policy for
% different Zs.
w_t_Zg = zeros(size(Model.Numerics.ZGrid,1),1);
for iZ = 1:size(Model.Numerics.ZGrid,1)

    w_t_Zg( iZ , 1 ) = OptimalWageSetting( Model.Numerics.ZGrid(iZ,1) , V_tplus1_wp , L , D , Pitplus1, a_tplus1 , Model );
    
end
w_t_Zp = polyfit( Model.Numerics.ZGrid , w_t_Zg , Model.Numerics.PolyOrder );
w_min  = polyval( w_t_Zp , Model.Numerics.ZLow);
w_max  = polyval( w_t_Zp , Model.Numerics.ZUp );
Z_t_wp = polyfit( w_t_Zg , Model.Numerics.ZGrid , Model.Numerics.PolyOrder );

% This part solves the first part of the value function that is the value
% of a firm when it is not subject to DNWR.
Objectiveg = ( UtilityFunction( w_t_Zg , Model.Numerics.ZGrid , L , Model ) ...
            + (Beta.*exp(-D)).*polyval( V_tplus1_wp , w_t_Zg./((1+Pitplus1).*(1+a_tplus1)) ) );
Objectivep = polyfit( Model.Numerics.ZGrid , Objectiveg , Model.Numerics.PolyOrder );
V_t_NoDNWR = PolyFZInt( Objectivep , 0 , Model.Numerics.ZLow , Model.Numerics.ZUp , Model );
                
% This part solves for the value function polynomial coefficients.
wHatg= (((Eta./(Eta-1)).*Model.Numerics.ZGrid).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) ); 
wHat= (((Eta./(Eta-1)).*Model.Numerics.ZUp).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) );        
wUp = 1.1.*wHat;
GridPoints = Model.Numerics.wPoints;
wGrid = (cumsum(ones(GridPoints,1))-1)*wUp/(GridPoints-1);

V_t_wg = zeros(size(wGrid,1),1);
for iw = 1:size(wGrid,1)

    thisw = wGrid( iw , 1 );    
    
    Z_t_thisw = max(min(polyval( Z_t_wp , thisw ),Model.Numerics.ZUp),Model.Numerics.ZLow);
    
    V_t_w_DNWR_NonBinding = PolyFZInt( Objectivep , 0 , Z_t_thisw , Model.Numerics.ZUp , Model );
                         
    RestrictedObjectiveg = ( UtilityFunction( thisw , Model.Numerics.ZGrid , L , Model ) ...
            + (Beta.*exp(-D)).*polyval( V_tplus1_wp , thisw./((1+Pitplus1).*(1+a_tplus1)) ) );
    ZUpg = ( RestrictedObjectiveg >= 0 );
    if ( sum(ZUpg) == 0 )
        V_t_w_DNWR_Binding = 0;
    else
        RestrictedObjectivep = polyfit( Model.Numerics.ZGrid(ZUpg,:), RestrictedObjectiveg(ZUpg,:) , min(sum(ZUpg)-1,Model.Numerics.PolyOrder) );     
        V_t_w_DNWR_Binding = PolyFZInt( RestrictedObjectivep , 0 , Model.Numerics.ZLow , Z_t_thisw , Model );
    end
    
    V_t_wg( iw , 1 ) = (1-Lamda).*V_t_NoDNWR  + ...
                       Lamda.*V_t_w_DNWR_NonBinding + ...
                       Lamda.*V_t_w_DNWR_Binding ;
    
end

V_t_wp = polyfit( wGrid , V_t_wg , Model.Numerics.PolyOrder);

end
        