function [ ZStar_ ] = ZStarCalculation( G_tminus1_wp , w_t_Zp , Z_t_wp , Pit , a_t , L , Model )
%ZPlusCalculation Calculates ZStar for the construction of the aggregates.

ZGrid = Model.Numerics.ZGrid;
ZUp = Model.Numerics.ZUp;
ZLow = Model.Numerics.ZLow;
Eta = Model.Parameters.Eta;
Gam = Model.Parameters.Gamma;
Lamda = Model.Parameters.Lamda;
ZPower = -( Eta - 1 ).*Gam./(Eta + Gam) ;

wHat_Z = (((Eta./(Eta-1)).*ZGrid).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) );
wHatUp = (((Eta./(Eta-1)).*ZUp).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) );
w_Z    = polyval( w_t_Zp , ZGrid );

NoDNWRg = ( max(wHat_Z./w_Z,1) ).^(Eta-1);
NoDNWRp = polyfit( ZGrid , NoDNWRg , Model.Numerics.PolyOrder );
NoDNWRPart = PolyFZInt( NoDNWRp , ZPower , ZLow , ZUp , Model );

Z_tminus1_wmin = polyval( Z_t_wp , min( G_tminus1_wp.breaks )./((1+Pit).*(1+a_t)) ); 
Z_tminus1_wmax = polyval( Z_t_wp , max( G_tminus1_wp.breaks )./((1+Pit).*(1+a_t)) );

ZLow_ = max( ZLow , Z_tminus1_wmin );
ZUp_  = ZUp;

StepSize = (ZUp_-ZLow_)/Model.Numerics.DZ;
ZGrid_ = ZLow_ + StepSize.*(cumsum(ones(Model.Numerics.DZ+1,1))-1);
w_Z_ = polyval( w_t_Zp , ZGrid_ );
wHat_Z_ = (((Eta./(Eta-1)).*ZGrid_).^(Gam./(Gam+Eta))).* ...
            ( L.^((Gam+1)./(Gam+Eta)) );
        
G_tminus1_wg = ppvalcutoff( G_tminus1_wp , w_Z_.*(1+Pit).*(1+a_t) , 0 , 1 );
g_tminus1_wp = ppder( G_tminus1_wp );

DNWRNotBindingg = G_tminus1_wg.*(( max(wHat_Z_./w_Z_,1)).^(Eta-1));
DNWRNotBindingp = polyfit( ZGrid_ , DNWRNotBindingg , Model.Numerics.PolyOrder );
DNWRNotBindingPart = PolyFZInt( DNWRNotBindingp , ZPower , ZLow_ , ZUp_ , Model );

ZLow_ = min( ZLow , Z_tminus1_wmax );
ZUp_  = min( ZUp , Z_tminus1_wmax );

if ( ZUp_ > ZLow_ )
    
    StepSize = (ZUp_-ZLow_)/Model.Numerics.DZ;
    ZGrid_ = ZLow_ + StepSize.*(cumsum(ones(Model.Numerics.DZ+1,1))-1);
    w_Z_ = polyval( w_t_Zp , ZGrid_ );
    wHat_Z_ = (((Eta./(Eta-1)).*ZGrid_).^(Gam./(Gam+Eta))).* ...
                ( L.^((Gam+1)./(Gam+Eta)) );

    DNWRBindingg = zeros( size(ZGrid_,1) , 1);
    GridPoints = Model.Numerics.wPoints;
    for iZ = 1:size(ZGrid_,1)

        wUp = max(g_tminus1_wp.breaks);
        wLow = max( min( w_Z_(iZ,1).*(1+Pit).*(1+a_t) , max(g_tminus1_wp.breaks)) , min(g_tminus1_wp.breaks));
        if ( wLow < wUp )
            wg = wLow+(cumsum(ones(GridPoints,1))-1).*(wUp-wLow)./(GridPoints-1);
            wIntg = ppvalcutoff( g_tminus1_wp , wg , 0 , 0 );
            wIntg = wIntg.*((wHat_Z_(iZ,1)./wg).^(Eta-1));
            wIntp = polyfit( wg , wIntg , Model.Numerics.PolyOrder );
            wIntp = polyint( wIntp );
            DNWRBindingg( iZ , 1 ) = polyval( wIntp , wUp ) - ...
                                        polyval( wIntp , wLow ) ;
        else
            DNWRBindingg( iZ , 1 ) = 0;
        end    

    end

    DNWRBindingp = polyfit( ZGrid_ , DNWRBindingg , Model.Numerics.PolyOrder );
    DNWRBindingPart = (((1+Pit).*(1+a_t))^(Eta-1)).*PolyFZInt( DNWRBindingp , ZPower , ZLow_ , ZUp_ , Model );

else

    DNWRBindingPart = 0;
    
end
    
    
ZStar_ = ( (1-Lamda).*max(0,NoDNWRPart) + Lamda.*max(0,DNWRNotBindingPart)  + ...
           + Lamda.*max(0,DNWRBindingPart) ).^(1./ZPower);

end

