clc;
clear;
warning('off','MATLAB:polyfit:RepeatedPointsOrRescale');

MyModel = DNWR.Model;

MyModel.Server = 0;
% Defining the output file
if MyModel.Server ==  0
   ResultsPath = 'C:\Bart\Research\Downward nom wage rigidities\Matlab\Results\';
elseif MyModel.Server == 1
   ResultsPath = '/data8/home/l1bxh01/Research/DNWR/Progs/'; 
else
   ResultsPath = '/home/bhobijn/DNWR/Results/';
end
OutputFile = strcat(ResultsPath,'LongRunPC.txt');

% Setting up the grid for which we calculate Long-Run Phillips Curve
InflationGrid = 0:10;
InflationGrid = InflationGrid./100;
nInflation = size( InflationGrid , 2 );
LamdaGrid = [ 0.4 0.8 0.8 0.9 0.99 ];
SigmaGrid = [ 0.25 0.25 0.2875 0.25 0.25 ];
nLamda = size( LamdaGrid , 2 );

HeaderStr = '       Lamda          Eta        PiBar         aBar          Beta        Sigma          L           u           h0        h04Q \n';
fid = fopen( OutputFile , 'w' );
count = fprintf(fid,HeaderStr);
status = fclose( fid );

% Constant parameters %
MyModel.Parameters.Lamda = 0.8;
MyModel.Parameters.Eta = 2.5;
MyModel.Parameters.PhiY = 1;
MyModel.Parameters.PhiPi = 0.3;
MyModel.Parameters.Beta = (1-0.02)^0.25;
MyModel.Parameters.aBar = 0.0066;
MyModel.Display = 0;

iModel = 0;

for iLamda = 1:nLamda
   
    MyModel.Parameters.Lamda = LamdaGrid(1,iLamda);
    MyModel.Parameters.Sigma = SigmaGrid(1,iLamda);
    
    for iInflation = 1:nInflation 

        iModel = iModel+1;
        msg = strcat('Model:  ',num2str(iModel),', of  ', num2str(nLamda.*nInflation) ); 
        MyModel.Name = msg;
        clc;
        disp(msg);        
        
        MyModel.Parameters.PiBar = ((1+InflationGrid(1,iInflation))^0.25)-1;

        SSSolved_ = MyModel.SteadyState.Solve;

        OutputMat = [ MyModel.Parameters.Lamda MyModel.Parameters.Eta ...
                      MyModel.Parameters.PiBar MyModel.Parameters.aBar MyModel.Parameters.Beta ...
                      MyModel.Parameters.Sigma MyModel.SteadyState.L ...
                      MyModel.SteadyState.u MyModel.SteadyState.h0 ...
                      MyModel.SteadyState.h04Q ] ;
        
        fid = fopen( OutputFile , 'a' );
        
        count = fprintf(fid, '%12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f \n' ,OutputMat);
        
        status = fclose( fid );

    end

end    
    

