clc;
clear;
warning('off','MATLAB:polyfit:RepeatedPointsOrRescale');
MyModel = DNWR.Model;

% Numerics settings
% MyModel.Numerics.wPoints = 15;
MyModel.Numerics.TPTol = 0.25;

% Basic Model Parameters
MyModel.Parameters.Eta = 2.5;
MyModel.Parameters.PiBar = ((1+0.02)^0.25)-1;
MyModel.Parameters.aBar = 0.0066;
MyModel.Parameters.PhiY = 1;
MyModel.Parameters.PhiPi = 0.3;
MyModel.Parameters.Beta = (1-0.02)^0.25;
MyModel.Numerics.T = 60;
MyModel.TransitionPath.a = ones(MyModel.Numerics.T+2,1).*MyModel.Parameters.aBar;
D = MyModel.TransitionPath.ShockPathAR1(-0.03,0.95); 

% Setting the length of the transitionpath and the shocks
if MyModel.Server ==  0
   ResultsPath = 'C:\Bart\Research\Downward nom wage rigidities\Matlab\Results\';
elseif MyModel.Server == 1
   ResultsPath = '/data8/home/l1bxh01/Research/DNWR/Progs/'; 
else
   ResultsPath = '/home/bhobijn/DNWR/Results/';
end

for iCurve = 1:3

    if iCurve == 1
        MyModel.Name = 'SRPC Panel a Lamda 80';
        OutputFile = strcat(ResultsPath,'SRPC Panel a Lamda 80 - Path.txt');
        MyModel.Parameters.Lamda = 0.8;
        MyModel.Parameters.Sigma = 0.2875;        
    elseif iCurve == 2
        MyModel.Name = 'SRPC Panel a Lamda 90';
        OutputFile = strcat(ResultsPath,'SRPC Panel a Lamda 90 - Path.txt');
        MyModel.Parameters.Lamda = 0.9;
        MyModel.Parameters.Sigma = 0.25; 
    else
        MyModel.Name = 'SRPC Panel a Lamda 99';
        OutputFile = strcat(ResultsPath,'SRPC Panel a Lamda 99 - Path.txt');
        MyModel.Parameters.Lamda = 0.99;
        MyModel.Parameters.Sigma = 0.225;
    end

    % Solve for the Steady State
    MyModel.SteadyState.Solve;           

    % Solve for the transition path
    TPSolved = MyModel.TransitionPath.Solve;

    % Write the header and variables from the transition path to the output file
    HeaderStr = '           t       Lamda          Eta           Pi            D            a            r            i         Beta        Sigma          L           u           h0        h04Q \n';
    fid = fopen( OutputFile , 'w' );
    count = fprintf(fid,HeaderStr);
    status = fclose( fid ); 

    tVec = 0:(MyModel.Numerics.T+1);
    tVec = tVec'; 
    T = MyModel.Numerics.T;
    OutputMat = [ tVec MyModel.Parameters.Lamda.*ones(T+2,1) MyModel.Parameters.Eta.*ones(T+2,1) ...
                      MyModel.TransitionPath.Pi MyModel.TransitionPath.D MyModel.TransitionPath.a MyModel.TransitionPath.r MyModel.TransitionPath.i  MyModel.Parameters.Beta.*ones(T+2,1) ...
                      MyModel.Parameters.Sigma.*ones(T+2,1) MyModel.TransitionPath.L...
                      MyModel.TransitionPath.u MyModel.TransitionPath.h0 ...
                      MyModel.TransitionPath.h04Q ] ;        
    fid = fopen( OutputFile , 'a' );
    count = fprintf(fid, '%12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f \n' ,OutputMat');
    status = fclose( fid );

end

