clc;
clear;
warning('off','MATLAB:polyfit:RepeatedPointsOrRescale');
MyModel = DNWR.Model;

% Numerics settings
% MyModel.Numerics.wPoints = 15;
MyModel.Numerics.TPTol = 0.25;

% Basic Model Parameters
MyModel.Parameters.Eta = 2.5;
MyModel.Parameters.PiBar = ((1+0.02)^0.25)-1;
MyModel.Parameters.aBar = 0.0066;
MyModel.Parameters.PhiY = 1;
MyModel.Parameters.PhiPi = 0.3;
MyModel.Parameters.Beta = (1-0.02)^0.25;
MyModel.Parameters.Lamda = 0.9;
MyModel.Parameters.Sigma = 0.25;
MyModel.Numerics.T = 60;
MyModel.TransitionPath.a = ones(MyModel.Numerics.T+2,1).*MyModel.Parameters.aBar; 

% Setting the length of the transitionpath and the shocks
if MyModel.Server ==  0
   ResultsPath = 'C:\Bart\Research\Downward nom wage rigidities\Matlab\Results\';
elseif MyModel.Server == 1
   ResultsPath = '/data8/home/l1bxh01/Research/DNWR/Progs/'; 
else
   ResultsPath = '/home/bhobijn/DNWR/Results/';
end

% Solve for the Steady State
MyModel.Name = 'SRPC Panel b';
MyModel.SteadyState.Solve; 

for iCurve = 1:3

    if iCurve == 1
        MyModel.Name = 'SRPC Panel b d=-0.03';
        OutputFile = strcat(ResultsPath,'SRPC Panel b deep - Path.txt');
        OutputFile2 = strcat(ResultsPath,'Wage distribution deep - G.txt');
        OutputFile3 = strcat(ResultsPath,'Wage distribution deep - H.txt');
        D = MyModel.TransitionPath.ShockPathAR1(-0.03,0.95);        
    elseif iCurve == 2
        MyModel.Name = 'SRPC Panel b d=-0.02';
        OutputFile = strcat(ResultsPath,'SRPC Panel b medium - Path.txt');
        D = MyModel.TransitionPath.ShockPathAR1(-0.02,0.95);
    else
        MyModel.Name = 'SRPC Panel a d=-0.01';
        MyModel.Numerics.TPTol = 0.1;
        OutputFile = strcat(ResultsPath,'SRPC Panel b shallow - Path.txt');
        D = MyModel.TransitionPath.ShockPathAR1(-0.01,0.95); 
    end              

    % Solve for the transition path
    TPSolved = MyModel.TransitionPath.Solve;

    % Write the header and variables from the transition path to the output file
    HeaderStr = '           t       Lamda          Eta           Pi            D            a            r            i         Beta        Sigma          L           u           h0        h04Q \n';
    fid = fopen( OutputFile , 'w' );
    count = fprintf(fid,HeaderStr);
    status = fclose( fid ); 

    tVec = 0:(MyModel.Numerics.T+1);
    tVec = tVec'; 
    T = MyModel.Numerics.T;
    OutputMat = [ tVec MyModel.Parameters.Lamda.*ones(T+2,1) MyModel.Parameters.Eta.*ones(T+2,1) ...
                      MyModel.TransitionPath.Pi MyModel.TransitionPath.D MyModel.TransitionPath.a MyModel.TransitionPath.r MyModel.TransitionPath.i  MyModel.Parameters.Beta.*ones(T+2,1) ...
                      MyModel.Parameters.Sigma.*ones(T+2,1) MyModel.TransitionPath.L...
                      MyModel.TransitionPath.u MyModel.TransitionPath.h0 ...
                      MyModel.TransitionPath.h04Q ] ;        
    fid = fopen( OutputFile , 'a' );
    count = fprintf(fid, '%12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f \n' ,OutputMat');
    status = fclose( fid );

    % For the benchmark case of the deep recession, save the distributions
    % of wages and log wage changes.
    if iCurve == 1 
       
        dlnWVec = -50:1:51 ;
        dlnWVec = dlnWVec'./200-0.0025;

        OutputMat = zeros( size(dlnWVec,1) , 4 );
        OutputMat(:,1) = dlnWVec;

        for idlnW = 1:size(dlnWVec,1);            

           OutputMat(idlnW,2) = MyModel.TransitionPath.H( dlnWVec(idlnW , 1 ) , 0 );
           OutputMat(idlnW,3) = MyModel.TransitionPath.H( dlnWVec(idlnW , 1 ) , 2 );
           OutputMat(idlnW,4) = MyModel.TransitionPath.H( dlnWVec(idlnW , 1 ) , 12 );

        end
        fid = fopen( OutputFile3 , 'w' );
        count = fprintf(fid, '%12.8f %12.8f %12.8f %12.8f \n' ,OutputMat');
        status = fclose( fid );

        OutputMat = MyModel.TransitionPath.G_wp(1).breaks';
        OutputMat = [ OutputMat MyModel.TransitionPath.G(MyModel.TransitionPath.G_wp(1).breaks',0) ];
        OutputMat = [ OutputMat MyModel.TransitionPath.G_wp(3).breaks' ];
        OutputMat = [ OutputMat MyModel.TransitionPath.G(MyModel.TransitionPath.G_wp(3).breaks',2) ];
        OutputMat = [ OutputMat MyModel.TransitionPath.G_wp(13).breaks' ];
        OutputMat = [ OutputMat MyModel.TransitionPath.G(MyModel.TransitionPath.G_wp(13).breaks',12) ];

        fid = fopen( OutputFile2 , 'w' );
        count = fprintf(fid, '%12.8f %12.8f %12.8f %12.8f %12.8f %12.8f \n' ,OutputMat');
        status = fclose( fid );
        
    end
    
end

